import { showMessage, hideMessage } from 'react-native-flash-message';
import { View, TouchableOpacity, ActivityIndicator } from 'react-native';
import Text from './text';
import TextButton from './text-button';
import { ErrorSymbolIcon } from './icons/error-symbol';
import { ClearSymbolIcon } from './icons/clear-symbol';
import Spinner from './spinner';

type SnackBarVariant = 'default' | 'danger' | 'success';

interface SnackBarProps {
  message: string;
  variant?: 'default' | 'danger' | 'success';
  loading?: boolean;
  buttonText?: string;
  duration?: number;
}

// 스타일 및 아이콘 설정
const getVariantStyles = (variant: SnackBarVariant) => {
  switch (variant) {
    case 'success':
      return {
        backgroundColor: 'bg-emerald-50',
        textColor: 'emerald-700',
        icon: 'check-circle',
      };
    case 'danger':
      return {
        backgroundColor: 'bg-red-50',
        textColor: 'red-700',
        icon: 'error',
      };
    default:
      return {
        backgroundColor: 'bg-gray-50',
        textColor: 'gray-700',
        icon: 'info',
      };
  }
};

// App.tsx에서 사용할 스타일 설정
export const flashMessageStyle = {
  backgroundColor: 'transparent', // 배경 투명
  padding: 0,
  margin: 0,
};

const CustomSnackBarContent = ({
  message,
  variant = 'default',
  loading = false,
  buttonText = '확인',
}: Omit<SnackBarProps, 'duration'>) => {
  const styles = getVariantStyles(variant);

  const renderIcon = () => {
    if (loading) {
      return (
        <View>
          <Spinner size="xsmall" />
        </View>
      );
    }

    switch (variant) {
      case 'danger':
        return <ErrorSymbolIcon />;
      case 'success':
        return <ClearSymbolIcon />;
      default:
        return null;
    }
  };

  return (
    <View
      className={`
      flex-row items-center justify-between 
      h-[60px]
      p-[16px]
      mx-4 mt-4
      bg-gray-900  
      rounded-xl 
      shadow-lg
    `}
    >
      <View className="flex-row items-center flex-1">
        {renderIcon()}
        <Text
          face="body"
          size="large"
          weight="regular"
          textColor="white"
          className="ml-[6px] flex-1"
        >
          {message}
        </Text>
      </View>

      <TextButton
        text={buttonText}
        variant="brand"
        underline={true}
        onPress={() => hideMessage()}
        size="medium"
      />
    </View>
  );
};

let isSnackBarVisible = false;

const showSnackBar = ({
  message,
  variant = 'default',
  loading = false,
  buttonText = '확인',
  duration = 3000,
}: SnackBarProps) => {
  if (!isSnackBarVisible) {
    isSnackBarVisible = true;
    showMessage({
      message: '',
      duration: duration,
      backgroundColor: 'transparent',
      hideStatusBar: false,
      renderCustomContent: () => (
        <CustomSnackBarContent
          message={message}
          variant={variant}
          loading={loading}
          buttonText={buttonText}
        />
      ),
      onHide: () => {
        isSnackBarVisible = false;
      },
    });
  } else {
    showMessage({
      message: '',
      duration: duration,
      backgroundColor: 'transparent',
      hideStatusBar: false,
      renderCustomContent: () => (
        <CustomSnackBarContent
          message={message}
          variant={variant}
          loading={loading}
          buttonText={buttonText}
        />
      ),
    });
  }
};

export default showSnackBar;
